Learn R Programming

stochcorr (version 0.0.1)

dvmp: Probability transition density function for von Mises process

Description

dvmp evaluates the transition density for von Mises process

Usage

dvmp(theta, t, theta_0, lambda, sigma, mu)

Value

dvmp gives the transition density function of the von Mises process

Arguments

theta

vector of data

t

time step \(\Delta t\)

theta_0

initial value

lambda

lambda

sigma

sigma

mu

mu

Details

See section 2 of Majumdar and Laha (2024) doi:10.48550/arXiv.2412.06343.