Learn R Programming

stochcorr (version 0.0.1)

rtraj.cbm: Simulate circular Brownian motion

Description

rtraj.cbm returns a simulated path of a circular Brownian motion for given parameters

Usage

rtraj.cbm(n, theta_0, dt, sigma, burnin=1000)

Value

A vector of length n of the simulated path from circular Brownian motion

Arguments

n

number of steps in the simulated path

theta_0

initial point

dt

Time step

sigma

volatility parameter

burnin

number of initial samples to be rejected (Default is 1000)

Details

Let \(\theta_t\) evolve according to a circular Brownian motion given by, $$d\theta_t=\sigma dW_t$$

We simulate \(\theta_t\) by simulating from its transition density.