Learn R Programming

stochcorr (version 0.0.1)

rtraj.vmp: Simulate von Mises process

Description

rtraj.vmp returns a simulated path of a von Mises process for given parameters

Usage

rtraj.vmp(n, theta_0, dt, mu, lambda, sigma)

Value

A vector of length n of the simulated path from von Mises process

Arguments

n

number of steps in the simulated path

theta_0

initial point

dt

Time step

mu

mean parameter

lambda

drift parameter

sigma

volatility parameter

Details

Let \(\theta_t\) evolve according to a von Mises process given by, $$d\theta_t=-\lambda\sin(\theta_t-\mu)dt+\sigma dW_t$$

We simulate \(\theta_t\) by the Euler-Maruyama discretization of the above SDE.