rtraj.cbm returns a simulated path of a circular Brownian motion for given parameters
rtraj.cbm(n, theta_0, dt, sigma, burnin=1000)A vector of length n of the simulated path from circular Brownian motion
number of steps in the simulated path
initial point
Time step
volatility parameter
number of initial samples to be rejected (Default is 1000)
Let \(\theta_t\) evolve according to a circular Brownian motion given by, $$d\theta_t=\sigma dW_t$$
We simulate \(\theta_t\) by simulating from its transition density.