rtraj.vmp returns a simulated path of a von Mises process for given parameters
rtraj.vmp(n, theta_0, dt, mu, lambda, sigma)A vector of length n of the simulated path from von Mises process
number of steps in the simulated path
initial point
Time step
mean parameter
drift parameter
volatility parameter
Let \(\theta_t\) evolve according to a von Mises process given by, $$d\theta_t=-\lambda\sin(\theta_t-\mu)dt+\sigma dW_t$$
We simulate \(\theta_t\) by the Euler-Maruyama discretization of the above SDE.